@@ -21,7 +21,7 @@ impl Spawned {
 		}
 	}
 
-	fn get_results(&self) -> Result<Vec<String>, LizError> {
+	fn join(&self) -> Result<Vec<String>, LizError> {
 		loop {
 			{
 				let lock = self.results.read().unwrap();
@@ -59,7 +59,7 @@ pub fn spawn(path: String, args: Option<Vec<String>>) -> Spawned {
 	let spawned = Spawned::new();
 	let spawned_clone = spawned.clone();
 	thread::spawn(move || {
-		let returned = crate::runs(exec_path, args);
+		let returned = crate::run(exec_path, args);
 		{
 			let mut lock = spawned_clone.results.write().unwrap();
 			*lock = Some(returned);
@@ -69,12 +69,12 @@ pub fn spawn(path: String, args: Option<Vec<String>>) -> Spawned {
 }
 
 pub fn join(spawned: Spawned) -> Result<Vec<String>, LizError> {
-	spawned.get_results()
+	spawned.join()
 }
 
-pub fn cmd<A: AsRef<str>, P: AsRef<Path>>(
+pub fn cmd<S: AsRef<str>, P: AsRef<Path>>(
 	name: &str,
-	args: &[A],
+	args: &[S],
 	dir: P,
 	print: bool,
 	throw: bool,
@@ -112,7 +112,7 @@ pub fn pause() {
   let stdout = std::io::stdout();
   let mut reader = std::io::stdin();
   let mut buffer = [0;1];
-  print!("Press any key to continue...");
+  print!("Press enter to continue...");
   stdout.lock().flush().unwrap();
   reader.read_exact(&mut buffer).unwrap();
 }
