@@ -11,7 +11,12 @@ pub mod texts;
 pub mod trans;
 pub mod utils;
 
-mod wizard;
+mod wiz_all;
+mod wiz_codes;
+mod wiz_execs;
+mod wiz_files;
+mod wiz_texts;
+mod wiz_trans;
 
 pub type LizError = Box<dyn Error + Send + Sync>;
 
@@ -78,7 +83,7 @@ pub fn race(path: impl AsRef<Path>, handler: &Lua) -> Result<Vec<String>, LizErr
             match json_multi {
                 Ok(json_multi) => result = Some(Ok(json_multi)),
                 Err(e) => {
-                    let mut msg = format!("Error on posting {} with message:\n", path_display);
+                    let mut msg = format!("Error on transforming the returned values of {} with message:\n", path_display);
                     let liz = utils::get_liz(ctx);
                     if let Some(liz) = liz {
                         if let Ok(err) = liz.get::<_, String>("err") {
@@ -118,7 +123,7 @@ pub fn rise(args: Option<Vec<String>>) -> Result<Lua, LizError> {
     let handler = Lua::new();
     let mut error: Option<LizError> = None;
     handler.context(|ctx| {
-        if let Err(err) = wizard::inject_all(ctx, args) {
+        if let Err(err) = wiz_all::inject_all(ctx, args) {
             error = Some(err);
         }
     });
